@@ -11,7 +11,7 @@ dat <- data.frame("values" = c(swept[, 1], swept[, 2]),
 ccc <- cccUst(dat, "values", "method")
 names(ccc) <- NULL
 
-lin <- propr:::linRcpp(rho@matrix, rho@logratio)
+lin <- propr:::linRcpp(rho@matrix, as.matrix(rho@logratio))
 
 test_that("linRcpp performs Z-transformation correctly (alr)", {
 
